resttools.make_repeated_rests_from_time_signature
=================================================

.. autofunction:: abjad.tools.resttools.make_repeated_rests_from_time_signature.make_repeated_rests_from_time_signature
